@@ -3,21 +3,16 @@ from tenyksclient.client import Client, run_client
 
 class TenyksSearch(Client):
 
-    irc_message_filters = {
+    message_filters = {
         'search': r'^search (.*)$',
     }
     direct_only = True
 
     def handle(self, data, match, filter_name):
         query = match.groups()[0]
-        self.send('{nick}: You will be able to search for "{query}" later.'.format(
-                    nick=data['nick'], query=query), data=data)
-
-
-def main():
-    search = TenyksSearch()
-    run_client(search)
-
+        self.send('{nick_from}: You will be able to search for "{query}" later.'.format(
+                    nick_from=data['nick_from'], query=query), data=data)
 
 if __name__ == '__main__':
-    main()
+    search = TenyksSearch()
+    run_client(search)
